pub enum IsqType {
Show 22 variants
Q4_0,
Q4_1,
Q5_0,
Q5_1,
Q8_0,
Q8_1,
Q2K,
Q3K,
Q4K,
Q5K,
Q6K,
Q8K,
HQQ8,
HQQ4,
F8E4M3,
AFQ8,
AFQ6,
AFQ4,
AFQ3,
AFQ2,
F8Q8,
MXFP4,
}Expand description
In-situ quantization type specifying the format to apply to model weights.
Variants
Q4_0
Q4_1
Q5_0
Q5_1
Q8_0
Q8_1
Q2K
Q3K
Q4K
Q5K
Q6K
Q8K
HQQ8
HQQ4
F8E4M3
AFQ8
AFQ6
AFQ4
AFQ3
AFQ2
F8Q8
MXFP4
Implementations
Sourceimpl IsqType
impl IsqType
Sourcepub fn pack_factor(&self, dtype: DType) -> usize
pub fn pack_factor(&self, dtype: DType) -> usize
Factor by which the weight size is reduced over the given dtype. original size / pack factor = quantized size
pub fn get_max_isq_cpu_threads(&self) -> Option<NonZeroUsize>